use chrono::{DateTime, Utc};
use serde::{Serialize, Serializer};

#[derive(Debug, Serialize)]
pub struct User {
    pub id: i32,
    pub username: String,
    pub password: String,
    pub role: Role,

    pub created_at: DateTime<Utc>,
    pub last_active: DateTime<Utc>,
}

#[derive(sqlx::Type, Debug)]
#[repr(i32)]
pub enum Role {
    Viewer = 1,
    Editor = 2,
    Manager = 3,
    Admin = 4,
}

impl Serialize for Role {
    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
    where
        S: Serializer,
    {
        serializer.serialize_str(match self {
            Role::Viewer => "viwer",
            Role::Editor => "editor",
            Role::Manager => "manager",
            Role::Admin => "admin",
        })
    }
}

impl From<i32> for Role {
    fn from(value: i32) -> Self {
        match value {
            1 => Self::Viewer,
            2 => Self::Editor,
            3 => Self::Manager,
            4 => Self::Admin,
            _ => unreachable!("Role should never be outside 1-4")
        }
    }
}
