use std::sync::Arc;

use axum::{
    extract::{Path, State},
    response::IntoResponse,
};
use sqlx::query_as;
use tracing::error;

use crate::{
    model::user::User,
    state::AppState,
    templates::{Page, PageData},
};

pub async fn get_user(
    State(state): State<Arc<AppState>>,
    Path(user_id): Path<i32>,
) -> impl IntoResponse {
    let user = match query_as!(User, r#"SELECT * FROM users WHERE id = $1"#, user_id)
        .fetch_one(&state.pool)
        .await
    {
        Ok(user) => user,
        Err(why) => {
            error!("Getting user: {}", why);
            return Page::new(
                state
                    .hbs
                    .render::<PageData>("error.hbs", &Default::default()),
            );
        }
    };

    Page::new(
        state
            .hbs
            .render("error.hbs", &PageData { user: Some(user) }),
    )
}
